Creates a configuration object for a Markov random field (Potts model)
spatial field. Used as the spatial argument to srf_model().
Usage
mrf(method = c("exchange", "pseudo_likelihood"), n_aux_sweeps = 200L)Creates a configuration object for a Markov random field (Potts model)
spatial field. Used as the spatial argument to srf_model().
mrf(method = c("exchange", "pseudo_likelihood"), n_aux_sweeps = 200L)